<?php
/**
 * Plugin Name: WP User Ban Diba
 * Description: افزونه‌ای برای بن کردن کاربران در وردپرس و جلوگیری از ورود و خرید در ووکامرس.
 * Version: 1.0
 * Author: Amir Sheikhzadeh
 * Plugin URI: https://dibapc.com
 */

if (!defined('ABSPATH')) {
    exit;
}

// افزودن متاباکس برای بن کردن کاربر
function wp_user_ban_add_meta_box($user) {
    $banned = get_user_meta($user->ID, 'is_banned', true);
    ?>
    <h3>وضعیت بن کاربر</h3>
    <table class="form-table">
        <tr>
            <th><label for="wp_user_ban">کاربر بن شود؟</label></th>
            <td>
                <input type="checkbox" name="wp_user_ban" id="wp_user_ban" value="1" <?php checked($banned, 1); ?>>
            </td>
        </tr>
    </table>
    <?php
}
add_action('show_user_profile', 'wp_user_ban_add_meta_box');
add_action('edit_user_profile', 'wp_user_ban_add_meta_box');

// ذخیره وضعیت بن شدن
function wp_user_ban_save($user_id) {
    if (current_user_can('edit_user', $user_id)) {
        $is_banned = isset($_POST['wp_user_ban']) ? 1 : 0;
        update_user_meta($user_id, 'is_banned', $is_banned);
    }
}
add_action('personal_options_update', 'wp_user_ban_save');
add_action('edit_user_profile_update', 'wp_user_ban_save');

// جلوگیری از ورود کاربران بن شده
function wp_user_ban_prevent_login($user, $username, $password) {
    $is_banned = get_user_meta($user->ID, 'is_banned', true);
    if ($is_banned) {
        return new WP_Error('banned_user', 'این کاربر بن شده است.');
    }
    return $user;
}
add_filter('authenticate', 'wp_user_ban_prevent_login', 30, 3);

// جلوگیری از دسترسی کاربران بن شده به پنل مدیریت و صفحات سایت
function wp_user_ban_prevent_admin_access() {
    if (is_user_logged_in()) {
        $user_id = get_current_user_id();
        $is_banned = get_user_meta($user_id, 'is_banned', true);

        // اگر کاربر بن شده باشد
        if ($is_banned) {
            wp_logout(); // خروج اجباری کاربر
            wp_redirect(home_url()); // هدایت به صفحه اصلی
            exit;
        }
    }
}
add_action('admin_init', 'wp_user_ban_prevent_admin_access');
add_action('template_redirect', 'wp_user_ban_prevent_admin_access');

// جلوگیری از دسترسی کاربران بن شده به صفحات خرید ووکامرس
if (in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')))) {
    function wp_user_ban_prevent_woocommerce_purchase() {
        if (is_user_logged_in()) {
            $user_id = get_current_user_id();
            $is_banned = get_user_meta($user_id, 'is_banned', true);

            // اگر کاربر بن شده باشد
            if ($is_banned) {
                // پاک کردن سبد خرید کاربر
                WC()->cart->empty_cart();

                // هدایت کاربر به صفحه حساب یا صفحه دلخواه دیگر
                wc_add_notice('شما بن شده‌اید و امکان خرید ندارید.', 'error');
                wp_redirect(home_url()); // هدایت به صفحه اصلی
                exit;
            }
        }
    }
    add_action('template_redirect', 'wp_user_ban_prevent_woocommerce_purchase');

    // جلوگیری از خرید کاربران بن شده (در فرایند پرداخت)
    function wp_user_ban_block_checkout_process($valid) {
        if (is_user_logged_in()) {
            $user_id = get_current_user_id();
            $is_banned = get_user_meta($user_id, 'is_banned', true);

            // اگر کاربر بن شده باشد
            if ($is_banned) {
                wc_add_notice('شما بن شده‌اید و امکان تکمیل خرید را ندارید.', 'error');
                return false; // جلوگیری از ادامه فرایند پرداخت
            }
        }

        return $valid;
    }
    add_filter('woocommerce_checkout_process', 'wp_user_ban_block_checkout_process');
}
